@@ -32,7 +32,7 @@ from sqlalchemy import MetaData
 import inspect
 import importlib
 import click
-__version__ = "02.00.03"
+__version__ = "02.00.04"
 default_db = "<default -- nw.sqlite>"
 
 #  MetaData = NewType('MetaData', object)
@@ -883,6 +883,8 @@ def update_api_logic_server_run__and__config(project_name, abs_project_name, abs
                            replace_with="ApiLogicServer generated at:" + str(datetime.datetime.now()),
                            in_file=api_logic_server_run_py)
     actual_path = pathlib.Path(abs_project_name).absolute()
+    if os.name == "nt":  # windows
+        actual_path = get_os_url(actual_path)
     replace_string_in_file(search_for="\"project_dir\"",  # for logging project location
                            replace_with='"' + str(actual_path) + '"',
                            in_file=api_logic_server_run_py)
@@ -1187,7 +1189,7 @@ def version(ctx):
     click.echo(
         click.style(
             f'Recent Changes:\n'
-            "\t04/09/2021 - 02.00.03: Bug Fix - View names with spaces\n"
+            "\t04/09/2021 - 02.00.04: Bug Fix - View names with spaces\n"
             "\t03/30/2021 - 02.00.02: Create Services table to avoid startup issues\n"
             "\t03/23/2021 - 02.00.01: Minor doc changes, CLI argument simplification for default db_url\n"
             "\t03/17/2021 - 02.00.00: Create create_admin.sh, copy sqlite3 DBs locally, model_ext\n"
