@@ -482,10 +482,10 @@ class CodeGenerator(object):
                          for package, names in self.collector.items())
 
     def render_metadata_declarations(self):
-        if "sqlalchemy.ext.declarative" in self.collector:
+        if "sqlalchemy.ext.declarative" in self.collector:  # Manually Added for safrs (ApiLogicServer)
             return """
 ########################################################################################################################
-# Manually Added for safrs (ApiLogicServer), TODO: improve this crap 
+# Classes describing database for SqlAlchemy ORM, initially created by schema introspection.
 #
 from safrs import SAFRSBase
 
@@ -495,7 +495,7 @@ db = safrs.DB
 Base = db.Model
 metadata = Base.metadata
 
-NullType = db.String
+NullType = db.String  # datatype fixup
 TIMESTAMP= db.TIMESTAMP
 
 from sqlalchemy.dialects.mysql import *
@@ -670,6 +670,9 @@ from sqlalchemy.dialects.mysql import *
         # Manual edit:
         # replace invalid chars  TODO review ApiLogicServer
         table_name = model.table.name.replace("$", "_S_")
+        table_name = table_name.replace(" ", "_")
+        if model.table.name == "Alphabetical list of products DEBUG ONLY":
+            print("Debug Stop on table")
         rendered = "t_{0} = Table(\n{1}{0!r}, metadata,\n".format(table_name, self.indentation)
 
         for column in model.table.columns:
